@@ -1,3 +1,13 @@
+"""
+kombu.utils.eventio
+===================
+
+Evented IO support for multiple platforms.
+
+:copyright: (c) 2009 - 2011 by Ask Solem.
+:license: BSD, see LICENSE for more details.
+
+"""
 import select
 import socket
 
